=========================
Meta App Script SDK
=========================


`Документация
<http://metasdk.readthedocs.io/>`_



`Полный список примеров
<https://github.com/devision-io/metasdk/tree/master/metasdk/examples/>`_
